/*==============================================================*/
/* table : currency_code                                        */
/*==============================================================*/
create table if not exists currency_code
(
   currency_id                    int                            not null,
   currency                       varchar(64)                    not null,
   primary key (currency_id)
);

/*==============================================================*/
/* table : reviewers                                            */
/*==============================================================*/
create table if not exists reviewers
(
   reviewer_id                    int                            not null,
   reviewer_lastname              varchar(255),
   reviewer_firstname             varchar(255),
   reviewer_login                 varchar(50),
   reviewer_password              varchar(50),
   reviewer_email                 varchar(255),
   reviewer_phone                 varchar(50),
   reviewer_fax                   varchar(50),
   reviewer_address               text,
   reviewer_profile               text,
   reviewer_coordinator           tinyint(1),
   cfp_code                       int                            default 0,
   cfp_cat_id                     int                            default 0,
   primary key (reviewer_id)
);

/*==============================================================*/
/* index: reviewers_login_idx                                   */
/*==============================================================*/
create index reviewers_login_idx on reviewers
(
   reviewer_login
);

/*==============================================================*/
/* table : record_status                                        */
/*==============================================================*/
create table if not exists record_status
(
   status_id                      int                            not null,
   status_name                    varchar(128)                   not null,
   primary key (status_id)
);

/*==============================================================*/
/* table : document_types                                       */
/*==============================================================*/
create table if not exists document_types
(
   doc_type_id                    int                            not null,
   doc_type_name                  varchar(128)                   not null,
   primary key (doc_type_id)
);

/*==============================================================*/
/* table : default_letters                                      */
/*==============================================================*/
create table if not exists default_letters
(
   letter_id                      int                            not null,
   letter_subject                 varchar(255),
   letter_body                    text,
   status_id                      int,
   primary key (letter_id)   
);

/*==============================================================*/
/* table : languages                                            */
/*==============================================================*/
create table if not exists languages
(
   lang_id                        int                            not null,
   language                       varchar(128)                   not null,
   primary key (lang_id)
);

/*==============================================================*/
/* table : initiative_info                                      */
/*==============================================================*/
create table if not exists initiative_info
(
   initiative_id                  int                            not null,
   initiative_name                varchar(255)                   not null,
   lang_id                        int                            not null,
   background                     text,
   eligibility                    text,
   review_process                 text,
   proposal_format                text,
   copyright                      text,
   record_lifecycle               varchar(50),
   about_submitting               text,
   ia_name                        varchar(255),
   ia_contact                     varchar(255),
   ia_email                       varchar(255),
   ia_address                     varchar(255),
   ia_courier                     varchar(255),
   ia_phone                       varchar(255),
   ia_fax                         varchar(255),
   ia_courier_inst                text,
   ia_url                         varchar(255),
   admin_image_title              varchar(255),
   public_image_title             varchar(255),
   image_toolbar                  varchar(255),
   primary key (initiative_id)
 
);

/*==============================================================*/
/* table : initiative_setup                                     */
/*==============================================================*/
create table if not exists initiative_setup
(
   initiative_setup_id            int                            not null,
   lang_id                        int,
   host_url                       varchar(255),
   host_doc_dir                   text,
   public_info                    varchar(50),
   public_info_degree             varchar(50),
   minimum_score                  float(10,1),
   minimum_rank                   float(10,1),
   show_weights                   varchar(50),
   use_initiative_criteria        tinyint(1),
   use_cfp_criteria               tinyint(1),
   show_reviewers                 tinyint(1),
   show_reviewers_summary         tinyint(1),
   background_image               text,
   admin_header_background        text,
   public_header_background       text,
   criteria_rankings              int,
   multiple_cfps                  tinyint(1),
   public_attachments             tinyint(1),
   default_lang                   int,
   listname                       varchar(255),
   primary key (initiative_setup_id)
   
);

/*==============================================================*/
/* table : initiative_criteria                                  */
/*==============================================================*/
create table if not exists initiative_criteria
(
   i_criteria_id                  int                            not null,
   i_criteria_name                text,
   i_criteria_weight              float(10,1),
   i_high_rank                    varchar(50),
   i_low_rank                     varchar(50),
   primary key (i_criteria_id)
);

/*==============================================================*/
/* table : coordinators                                         */
/*==============================================================*/
create table if not exists coordinators
(
   coordinator_id                 int                            not null,
   coordinator_lastname           varchar(255),
   coordinator_firstname          varchar(255),
   coordinator_login              varchar(50),
   coordinator_password           varchar(50)                    not null,
   coordinator_email              varchar(255),
   coordinator_public_email       varchar(255),
   coordinator_admin_email        varchar(255),
   coordinator_phone              varchar(50),
   coordinator_fax                varchar(50),
   coordinator_address            varchar(255),
   receive_public_emails          tinyint(1),
   receive_admin_emails           tinyint(1),
   primary key (coordinator_id)
);

/*==============================================================*/
/* index: coord_login_idx                                       */
/*==============================================================*/
create index coord_login_idx on coordinators
(
   coordinator_login
);

/*==============================================================*/
/* table : faq                                                  */
/*==============================================================*/
create table if not exists faq
(
   faq_id                         int                            not null,
   faq_question                   text,
   faq_answer                     text,
   primary key (faq_id)
);

/*==============================================================*/
/* table : funding_agencies                                     */
/*==============================================================*/
create table if not exists funding_agencies
(
   agency_id                      int                            not null,
   agency_name                    varchar(255),
   agency_contact                 varchar(255),
   agency_email                   varchar(255),
   agency_phone                   varchar(50),
   agency_url                     varchar(255),
   primary key (agency_id)
);

/*==============================================================*/
/* table : phrases                                              */
/*==============================================================*/
create table if not exists phrases
(
   phrase_id                      int                            not null,
   lang_id                        int                            not null,
   phrase                         varchar(255)                   not null,
   primary key (phrase_id, lang_id)   
);

/*==============================================================*/
/* table : cfp_info                                             */
/*==============================================================*/
create table if not exists cfp_info
(
   cfp_code                       int                            not null,
   cfp_startdate                  date,
   cfp_title                      varchar(255),
   cfp_background                 text,
   cfp_objectives                 text,
   cfp_focus                      text,
   cfp_deadline                   date,
   cfp_report_deadline            date,
   cfp_format                     varchar(255),
   cfp_maxaward                   float(20,2),
   cfp_totalfunds                 float(20,2),
   cfp_proposal_review_deadline   date,
   cfp_report_review_deadline     date,
   currency_id                    int,
   first_reminder                 date,
   second_reminder                date,
   third_reminder                 date,
   primary key (cfp_code)   
);

/*==============================================================*/
/* table : cfp_category                                         */
/*==============================================================*/
create table if not exists cfp_category
(
   cfp_cat_id                     int                            not null,
   cfp_code                       int,
   cfp_cat_name                   varchar(255)                   not null,
   primary key (cfp_cat_id)   
);

/*==============================================================*/
/* table : proponent_record                                     */
/*==============================================================*/
create table if not exists proponent_record
(
   tracking_code                  int                            not null,
   previous_tracking_code         int,
   cfp_cat_id                     int,
   date_submitted                 date,
   date_last_updated              date,
   proponent_password             varchar(50),
   proposal_title                 varchar(255),
   proposal_score_sum             float(10,1),
   proposal_rank                  float(10,1),
   requested_amount               float(20,2),
   awarded_amount                 float(20,2),
   award_comment                  text,
   status_id                      int,
   cfp_code                       int,
   proponent_institution          varchar(255),
   proponent_address              varchar(255),
   proponent_phone                varchar(50),
   proponent_fax                  varchar(50),
   proponent_email                varchar(255),
   proponent_url                  varchar(255),
   proponent_leader_firstname     varchar(128),
   proponent_leader_lastname      varchar(128),
   proponent_leader_initial       varchar(5),
   proponent_leader_affiliation   varchar(255),
   proponent_leader_address       varchar(255),
   proponent_leader_phone         varchar(50),
   proponent_leader_fax           varchar(50),
   proponent_leader_email         varchar(255),
   proposal_hide                  tinyint(1),
   proponent_citizenship          varchar(128),
   proponent_residency            varchar(128),
   project_country                varchar(128),
   project_date                   varchar(255),
   primary key (tracking_code)
);

/*==============================================================*/
/* table : cfp_criteria                                         */
/*==============================================================*/
create table if not exists cfp_criteria
(
   cfp_criteria_id                int                            not null,
   cfp_code                       int,
   cfp_criteria_name              varchar(255),
   cfp_criteria_weight            float(10,1),
   cfp_high_rank                  varchar(50),
   cfp_low_rank                   varchar(50),
   primary key (cfp_criteria_id)   
);

/*==============================================================*/
/* table : sent_messages                                        */
/*==============================================================*/
create table if not exists sent_messages
(
   sent_message_id                int                            not null,
   tracking_code                  int,
   letter_id                      int,
   date_sent                      date,
   recipient1                     varchar(255),
   recipient2                     varchar(255),
   custom_body                    text,
   custom_subject                 varchar(255),
   primary key (sent_message_id)
);

/*==============================================================*/
/* table : reviewer_assignment                                  */
/*==============================================================*/
create table if not exists reviewer_assignment
(
   assignment_id                  int                            not null,
   reviewer_id                    int                            not null,
   cfp_code                       int                            not null,
   tracking_code                  int                            not null,
   proposal_review_completed      tinyint(1),
   proposal                       tinyint(1),
   report                         tinyint(1),
   report_review_completed        tinyint(1),
   primary key (assignment_id)
);

/*==============================================================*/
/* table : documents                                            */
/*==============================================================*/
create table if not exists documents
(
   doc_id                         int                            not null,
   tracking_code                  int                            not null,
   doc_type_id                    int                            not null,
   doc_title                      varchar(255)                   not null,
   doc_filename                   text                           not null,
   doc_date                       date                           not null,
   doc_abstract                   text,
   primary key (doc_id)
);

/*==============================================================*/
/* table : admin_documents                                      */
/*==============================================================*/
create table if not exists admin_documents
(
   doc_id                         int                            not null,
   tracking_code                  int,
   doc_type_id                    int,
   cfp_code                       int,
   doc_title                      varchar(255),
   doc_filename                   text,
   doc_date                       date,
   primary key (doc_id)
);

/*==============================================================*/
/* table : report_appraisal                                     */
/*==============================================================*/
create table if not exists report_appraisal
(
   report_appraisal_id            int                            not null,
   reviewer_id                    int                            not null,
   tracking_code                  int                            not null,
   report_comments                text,
   primary key (report_appraisal_id)
);

/*==============================================================*/
/* table : proposal_appraisal                                   */
/*==============================================================*/
create table if not exists proposal_appraisal
(
   appraisal_id                   int                            not null,
   reviewer_id                    int,
   tracking_code                  int,
   appraisal_score                float(10,1),
   appraisal_rank                 float(10,1),
   appraisal_comment              text,
   i_criteria_id                  int,
   cfp_criteria_id                int,
   primary key (appraisal_id)
);

/*==============================================================*/
/* table : researchers                                          */
/*==============================================================*/
create table if not exists researchers
(
   researcher_id                  int                            not null,
   tracking_code                  int,
   researcher_firstname           varchar(255),
   researcher_lastname            varchar(255),
   researcher_initial             varchar(5),
   researcher_phone               varchar(50),
   researcher_fax                 varchar(50),
   researcher_email               varchar(255),
   researcher_citizenship         varchar(255),
   researcher_residency           varchar(255),
   researcher_org                 varchar(255),
   primary key (researcher_id)
);

/*==============================================================*/
/* table : public_comments                                      */
/*==============================================================*/
create table if not exists public_comments
(
   comment_id                     int                            not null,
   tracking_code                  int                            not null,
   comment_body                   text                           not null,
   comment_date                   date                           not null,
   comment_name                   varchar(255),
   comment_email                  varchar(255),
   primary key (comment_id)
);

/*==============================================================*/
/* table : admin_discussion                                     */
/*==============================================================*/
create table if not exists admin_discussion
(
   discussion_id                  int                            not null,
   doc_id                         int,
   discuss_level                  int,
   discuss_parent                 int,
   discuss_subject                varchar(255),
   discuss_author                 varchar(255),
   discuss_email                  varchar(255),
   discuss_date                   date,
   discuss_message                text,
   discuss_replies                int,
   discuss_attachment             text,
   primary key (discussion_id)
);

/*==============================================================*/
/* table : discussion                                           */
/*==============================================================*/
create table if not exists discussion
(
   discussion_id                  int                            not null,
   doc_id                         int,
   discuss_level                  int,
   discuss_parent                 int                            default 0,
   discuss_subject                varchar(255)                   not null,
   discuss_author                 varchar(255),
   discuss_email                  varchar(255),
   discuss_date                   datetime                       not null,
   discuss_message                text                           not null,
   discuss_replies                int,
   discuss_attachment             text,
   primary key (discussion_id)
);

drop table if exists messages;

create table messages
(list         varchar(40) not null,
 messageid    integer not null,
 created      date,
 hdrfrom      varchar(40),
 hdrsubject   varchar(100),
 hdrfromspc   varchar(100),
 messagedesc  text,
 primary key (list, messageid)
 );
 
 
 create index msglistidx on messages (list);
 create index msglididx on messages (messageid);

drop table if exists lists;

create table lists
(list     varchar(40) not null,
 listdesc varchar(200),
  listtopic text,
  primary key (list)
);

drop table if exists members;

create table members
(list              varchar(40) not null,
 memberemail       varchar(40) not null,
 fullname          varchar(100),
 datejoined        date,
 memberpassword    varchar(10),
 membersubtype     varchar(10),
 status            varchar(10),
 expire            date,
 acknowledge       varchar(3),
 approval          varchar(3),
 numberofapprovals integer(3),
 listadmin         varchar(3),
 adminmail         varchar(3),
 moderation        varchar(3),
 errormail         varchar(3),
 repro             varchar(3),
 holduser          varchar(3),
 sendhellomessage  varchar(3),
 userid            varchar(15),
 membercomments    varchar(200),
 primary key (list, memberemail)
 );

 create index msglistidx2 on members (list);
 
